summaryrefslogtreecommitdiffstats
path: root/examples/rainfall/main.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'examples/rainfall/main.cpp')
-rw-r--r--examples/rainfall/main.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/examples/rainfall/main.cpp b/examples/rainfall/main.cpp
index a4e316be..638fb842 100644
--- a/examples/rainfall/main.cpp
+++ b/examples/rainfall/main.cpp
@@ -4,7 +4,7 @@
** All rights reserved.
** For any questions to Digia, please use contact form at http://qt.digia.com
**
** This file is part of the QtDataVis3D module.
**
** Licensees holding valid Qt Enterprise licenses may use this file in
** accordance with the Qt Enterprise License Agreement provided with the
@@ -19,7 +19,7 @@
#include "rainfallchart.h"
#include <QGuiApplication>
-using namespace QtDataVis3D;
+using namespace QtDataVisualization;
int main(int argc, char **argv)
{
@@ -4,7 +4,7 @@
** For any questions to Digia, please use contact form at http://qt.digia.com
**
-** This file is part of the QtDataVis3D module.
+** This file is part of the QtDataVisualization module.
**
** Licensees holding valid Qt Enterprise licenses may use this file in